-----
iobes
-----

.. image:: https://img.shields.io/pypi/v/iobes
    :target: https://pypi.org/project/iobes/
    :alt: PyPI Version
.. image:: https://github.com/blester125/iobes/workflows/Unit%20Test/badge.svg
    :target: https://github.com/blester125/iobes/actions
    :alt: Actions Status
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code style: black

A light-weight library for creating span level annotations from token level decisions.
